@@ -83,6 +83,7 @@ class Database(object):
         'data_type': (lambda: random.choice(["date", "int", "bigint", "double", "varchar", "DATE", "DATE_J", "DATETIME", "TIMESTAMP(6)", "NUMBER", "VARCHAR2", "CHAR"])),
         'sector': lambda: random.choice(['6416', '6844', '6838', '6731', '6735', '6625', '6521', '6102', '6519', '6626', '6522', '6839', '6523', '6211', '6520', '6209', '6728', '6310', '6627', '6837', '6734'])
     }
+    VERBOSE = os.environ['PYDB_VERBOSE'] != 'False'
 
     def __init__(self, instance, schema, retry=None):
         """
@@ -137,7 +138,8 @@ class Database(object):
 
     def execute(self, sql):
         """Executa una sentència SQL."""
-        print(sql)
+        if (self.VERBOSE):
+            print(sql)
 
     def recreate_database(self):
         """Elimina i torna a crear una base de dades (MariaDB)."""
@@ -269,7 +271,8 @@ class Database(object):
           -a MariaDB utilitza txt_to_table
           -a Oracle utilitza _list_to_table_oracle
         """
-        print(str(table) + ": " + str(iterable))
+        if (self.VERBOSE):
+            print(str(table) + ": " + str(iterable))
         if table in self.data:
             self.data[table].append(iterable)
         else:
